==> kdepim-4.8.90.tar.xz: kdepim-4.8.90/ktimetracker/focusdetectornotifier.h <==
/*
 *     Copyright (C) 2007 by Mathias Soeken <msoeken@tzi.de>
 *                   2007 the ktimetracker developers
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the
 *      Free Software Foundation, Inc.
 *      51 Franklin Street, Fifth Floor
 *      Boston, MA  02110-1301  USA.
 *
 */

#ifndef KTIMETRACKER_FOCUS_DETECTOR_NOTIFIER_H
#define KTIMETRACKER_FOCUS_DETECTOR_NOTIFIER_H

#include <QObject>

class FocusDetector;
class TaskView;

/**
  Manages the FocusDetector for multiple TaskView instances, so only
  one timer is used for all.

  It starts and stops the timer when the list of taskviews is changing, so
  the timer has to be stopped only iff there is no taskview left.
 */
class FocusDetectorNotifier : public QObject
{
  Q_OBJECT

  public:
    virtual ~FocusDetectorNotifier();
    static FocusDetectorNotifier *instance();

  public:
    void attach( TaskView *view );
    void detach( TaskView *view );

    FocusDetector *focusDetector() const;

  private:
    FocusDetectorNotifier( QObject *parent = 0 );
    static FocusDetectorNotifier *mInstance;

    //@cond PRIVATE
    class Private;
    Private *const d;
    //@endcond
};

#endif // KTIMETRACKER_FOCUS_DETECTOR_NOTIFIER_H

==> kdepim-4.14.10.tar.xz: kdepim-4.14.10/ktimetracker/focusdetectornotifier.h <==
/*
 *     Copyright (C) 2007 by Mathias Soeken <msoeken@tzi.de>
 *                   2007 the ktimetracker developers
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the
 *      Free Software Foundation, Inc.
 *      51 Franklin Street, Fifth Floor
 *      Boston, MA  02110-1301  USA.
 *
 */

#ifndef KTIMETRACKER_FOCUS_DETECTOR_NOTIFIER_H
#define KTIMETRACKER_FOCUS_DETECTOR_NOTIFIER_H

#include <QObject>

class FocusDetector;
class TaskView;

/**
  Manages the FocusDetector for multiple TaskView instances, so only
  one timer is used for all.

  It starts and stops the timer when the list of taskviews is changing, so
  the timer has to be stopped only iff there is no taskview left.
 */
class FocusDetectorNotifier : public QObject
{
  Q_OBJECT

  public:
    virtual ~FocusDetectorNotifier();
    static FocusDetectorNotifier *instance();

  public:
    void attach( TaskView *view );
    void detach( TaskView *view );

    FocusDetector *focusDetector() const;

  private:
    explicit FocusDetectorNotifier( QObject *parent = 0 );
    static FocusDetectorNotifier *mInstance;

    //@cond PRIVATE
    class Private;
    Private *const d;
    //@endcond
};

#endif // KTIMETRACKER_FOCUS_DETECTOR_NOTIFIER_H
